PyTrakt
=======
.. image:: https://travis-ci.org/moogar0880/PyTrakt.svg
    :target: https://travis-ci.org/moogar0880/PyTrakt
    :alt: Travis CI Status

.. image:: https://pypip.in/d/trakt/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/trakt/
    :alt: Downloads

.. image:: https://pypip.in/v/trakt/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/trakt/
    :alt: Latest Version

.. image:: https://pypip.in/py_versions/trakt/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/trakt/
    :alt: Supported Python versions

.. image:: https://pypip.in/license/trakt/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/trakt/
    :alt: License

This module is designed to be a Pythonic interface to the `Trakt.tv <http://trakt.tv>`_.
REST API. The official documentation for which can be found `here <http://trakt.tv/api-docs/>`_.
trakt contains interfaces to all of the Trakt.tv functionality in an, ideally, easily
scriptable fashion. For more information on this module's contents and example usages
please see the `PyTrakt docs <http://pytrakt.readthedocs.org/en/latest/>`_.

More information about getting started and accessing the information you thirst for
can be found throughout the documentation below.


Installation
------------
There are two ways through which you can install trakt

Install Via Pip
^^^^^^^^^^^^^^^
To install with `pip <http://www.pip-installer.org/>`_, just run this in your terminal::

    $ pip install trakt

Get the code
^^^^^^^^^^^^
trakt is available on `GitHub <https://github.com/moogar0880/PyTrakt>`_.

You can either clone the public repository::

    $ git clone git://github.com/moogar0880/PyTrakt.git

Download the `tarball <https://github.com/moogar0880/PyTrakt/tarball/master>`_::

    $ curl -OL https://github.com/moogar0880/PyTrakt/tarball/master

Or, download the `zipball <https://github.com/moogar0880/PyTrakt/zipball/master>`_::

    $ curl -OL https://github.com/moogar0880/PyTrakt/zipball/master

Once you have a copy of the source, you can embed it in your Python package,
or install it into your site-packages easily::

    $ python setup.py install

